@@ -33,7 +33,7 @@ import ConfigParser as configparser  # noqa
 from cStringIO import StringIO  # noqa
 from pipes import quote  # noqa
 from urllib import urlencode, unquote  # noqa
-from urllib2 import HTTPError, HTTPSHandler, Request, build_opener  # noqa
+from urllib2 import HTTPError, HTTPSHandler, Request, build_opener, urlopen  # noqa
 from collections import Mapping  # noqa
 
 
